colour.models.dataset.s_log Module — Colour 0.3.0 documentation

# colour.models.dataset.s_log Module

## Sony S-Log Colourspace

Defines the S-Log colourspace:

- `S_LOG_COLOURSPACE`.

See also

RGB Colourspaces IPython Notebook

References

[1] | http://pro.sony.com/bbsccms/assets/files/mkt/cinema/solutions/slog_manual.pdf (Last accessed 13 April 2014)

`colour.models.dataset.s_log.` `S_LOG_PRIMARIES` = array([[ 0.73 , 0.28 ], [ 0.14 , 0.855], [ 0.1 , -0.05 ]])

  S-Log colourspace primaries.

  S_LOG_PRIMARIES : ndarray, (3, 2)

`colour.models.dataset.s_log.` `S_LOG_WHITEPOINT` = (0.31271, 0.32902)

  S-Log colourspace whitepoint.

  S_LOG_WHITEPOINT : tuple

`colour.models.dataset.s_log.` `S_LOG_TO_XYZ_MATRIX` = array([[ 0.70647263, 0.12880033, 0.11515559], [ 0.2709758 , 0.78660199, -0.05757779], [-0.00967771, 0.00460001, 1.09397807]])

  S-Log colourspace to CIE XYZ colourspace matrix.

  S_LOG_TO_XYZ_MATRIX : array_like, (3, 3)

`colour.models.dataset.s_log.` `XYZ_TO_S_LOG_MATRIX` = array([[ 1.50742141, -0.24582564, -0.17161413], [-0.51815464, 1.35539886, 0.12587938], [ 0.01551393, -0.0078739 , 0.91204765]])

  CIE XYZ colourspace to S-Log colourspace matrix.

  XYZ_TO_S_LOG_MATRIX : array_like, (3, 3)

`colour.models.dataset.s_log.` `S_LOG_TRANSFER_FUNCTION`(x)

  Transfer function from linear to S-Log colourspace.

  S_LOG_TRANSFER_FUNCTION : object

`colour.models.dataset.s_log.` `S_LOG_INVERSE_TRANSFER_FUNCTION`(x)

  Inverse transfer function from S-Log colourspace to linear.

  S_LOG_INVERSE_TRANSFER_FUNCTION : object

`colour.models.dataset.s_log.` `S_LOG_COLOURSPACE` = <colour.models.rgb_colourspace.RGB_Colourspace object at 0x102e29550>

  S-Log colourspace.

  S_LOG_COLOURSPACE : RGB_Colourspace